<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
import { couponForm, couponSearchForm, couponColumn } from '@/utils/coupon-form'
import InputSelect from '@/components/input-select'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/v2/coupon/point/page',
        newUrl: 'flower/api/v2/coupon/point',
        viewUrl: 'flower/api/v2/coupon/point',
        viewOnPath: true,
        editUrl: 'flower/api/v2/coupon/point',
        editMethodType: 'put',
        editOnPath: true,
        deleteUrl: 'flower/api/v2/coupon/point',
        deleteMethodType: 'delete',
        deleteOnPath: true,
        canEdit: (row) => row.status === 'inactive' || row.status === 'expired',
        canDelete: (row) =>
          row.status === 'inactive' || row.status === 'expired',
        onResetView: (row) => {
          this.$router.push(`${this.$route.path}/${row.id}`)
        },
        persistSelection: true,
        operationAttrs: {
          width: 160,
          fixed: 'right',
        },
        columns: [
          {
            label: '',
            type: 'selection',
            minWidth: 60,
          },
          ...couponColumn(),
          { label: '状态', prop: 'statusName', minWidth: 120 },
          { label: '发放数量', prop: 'couponAmount', minWidth: 120 },
          { label: '已兑换', prop: 'getNum', minWidth: 120 },
          { label: '库存', prop: 'unGetNum', minWidth: 120 },
          { label: '所需积分', prop: 'point', minWidth: 120 },
        ],
        searchForm: [
          {
            type: 'row',
            items: [...couponSearchForm()],
          },
        ],
        form: [
          ...couponForm(),
          {
            label: '领取后有效时间：',
            id: 'usageTimeNum',
            component: InputSelect,
            commonRules: true,
            commonFormat: true,
            commonFormatProps: ['usageTimeNum', 'usageTimeType'],
            el: {
              inputAttrs: {
                min: 1,
                max: 99999999,
                precision: 0,
                controls: false,
              },
              selectAttrs: {
                code: 'COUPON_USAGE_TIME_TYPE',
              },
            },
          },
          {
            label: '发放数量：',
            id: 'couponAmount',
            type: 'input-number',
            el: {
              precision: 0,
              min: 0,
              max: 99999999,
              controls: false,
            },
            rules: [
              { required: true, message: '请输入发放数量', trigger: 'blur' },
              {
                type: 'number',
                min: 1,
                message: '发放数量必须大于0',
                trigger: 'blur',
              },
            ],
          },
          {
            label: '积分数量：',
            id: 'point',
            type: 'input-number',
            el: {
              precision: 0,
              min: 1,
              max: 99999999,
              controls: false,
            },
            rules: {
              required: true,
              message: '请输入积分数量',
              trigger: 'blur',
            },
          },
        ],
        extraButtons: [
          {
            text: '上架',
            show: (row) =>
              (row.status === 'inactive' || row.status === 'expired') &&
              row.couponAmount > 0,
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要上架吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/api/v2/coupon/point/active/${row.id}`,
                  { method: 'put' }
                )
                if (code === 0) {
                  this.$message.success('上架成功')
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '下架',
            show: (row) => row.status === 'active',
            atClick: async (row) => {
              try {
                await this.$elBusUtil.confirm('确定要下架吗？')
                const { code } = await this.$elBusHttp.request(
                  `flower/api/v2/coupon/point/expire/${row.id}`,
                  { method: 'put' }
                )
                if (code === 0) {
                  this.$message.success('下架成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
        headerButtons: [
          {
            text: '批量上架',
            type: 'primary',
            disabled: (selected) =>
              selected.filter(
                (i) => i.status === 'inactive' || i.status === 'expired'
              ).length === 0,
            atClick: async (selected) => {
              try {
                const items = selected.filter(
                  (i) => i.status === 'inactive' || i.status === 'expired'
                )
                await this.$elBusUtil.confirm(
                  `确定要上架这${items.length}个商品吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/v2/coupon/point/batch/active',
                  {
                    data: { idList: items.map((i) => i.id) },
                    method: 'post',
                  }
                )
                if (code === 0) {
                  this.$message.success('上架成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '批量下架',
            type: 'primary',
            disabled: (selected) =>
              selected.filter((i) => i.status === 'active').length === 0,
            atClick: async (selected) => {
              try {
                const items = selected.filter((i) => i.status === 'active')
                await this.$elBusUtil.confirm(
                  `确定要下架这${items.length}个商品吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/v2/coupon/point/batch/expire',
                  {
                    data: { idList: items.map((i) => i.id) },
                    method: 'post',
                  }
                )
                if (code === 0) {
                  this.$message.success('下架成功')
                  this.$refs.crud.clearSelection()
                }
              } catch (e) {
                return false
              }
            },
          },
          {
            text: '批量删除',
            type: 'danger',
            disabled: (selected) =>
              selected.filter(
                (i) => i.status === 'inactive' || i.status === 'expired'
              ).length === 0,
            atClick: async (selected) => {
              try {
                const items = selected.filter(
                  (i) => i.status === 'inactive' || i.status === 'expired'
                )
                await this.$elBusUtil.confirm(
                  `确定要删除这${items.length}个商品吗？`
                )
                const { code } = await this.$elBusHttp.request(
                  'flower/api/v2/coupon/point/batch/del',
                  {
                    data: { idList: items.map((i) => i.id) },
                    method: 'post',
                  }
                )
                if (code === 0) {
                  this.$message.success('删除成功')
                }
              } catch (e) {
                return false
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '积分优惠券',
    }
  },
}
</script>

<style lang="scss" scoped>
.index {
}
</style>
